netapp_ontap.models.shelf_frus_psu API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_frus_psu`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfFrusPsuSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfFrusPsu object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `crest_factor: Size GET POST PATCH`

    The ratio of the peak voltage to the root-mean-square voltage

    Example: 92

  `model: str GET POST PATCH`

    The model field of the shelf_frus_psu.

    Example: 00

  `power_drawn: Size GET POST PATCH`

    Power drawn, in watts

    Example: 210

  `power_rating: Size GET POST PATCH`

    Power rating, in watts

    Example: 1600